@@ -213,6 +213,46 @@ class TestTLSStream:
         server_thread.join()
         server_sock.close()
 
+    @pytest.mark.parametrize('force_tlsv12', [
+        pytest.param(False, marks=[pytest.mark.skipif(not getattr(ssl, 'HAS_TLSv1_3', False),
+                                                      reason='No TLS 1.3 support')]),
+        pytest.param(True)
+    ], ids=['tlsv13', 'tlsv12'])
+    async def test_send_eof_not_implemented(self, server_context, ca, force_tlsv12):
+        def serve_sync():
+            conn, addr = server_sock.accept()
+            conn.sendall(b'hello')
+            conn.unwrap()
+            conn.close()
+
+        client_context = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
+        ca.configure_trust(client_context)
+        if force_tlsv12:
+            expected_pattern = r'send_eof\(\) requires at least TLSv1.3'
+            client_context.options |= ssl.OP_NO_TLSv1_3
+        else:
+            expected_pattern = r'send_eof\(\) has not yet been implemented for TLS streams'
+
+        server_sock = server_context.wrap_socket(socket.socket(), server_side=True,
+                                                 suppress_ragged_eofs=False)
+        server_sock.settimeout(1)
+        server_sock.bind(('127.0.0.1', 0))
+        server_sock.listen()
+        server_thread = Thread(target=serve_sync, daemon=True)
+        server_thread.start()
+
+        stream = await connect_tcp(*server_sock.getsockname())
+        async with await TLSStream.wrap(stream, hostname='localhost',
+                                        ssl_context=client_context) as wrapper:
+            assert await wrapper.receive() == b'hello'
+            with pytest.raises(NotImplementedError) as exc:
+                await wrapper.send_eof()
+
+            exc.match(expected_pattern)
+
+        server_thread.join()
+        server_sock.close()
+
 
 class TestTLSListener:
     async def test_handshake_fail(self, server_context):
